summaryrefslogtreecommitdiffstats
path: root/chrome_frame/bind_context_info.h
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-12 20:53:23 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-12 20:53:23 +0000
commit8ee65baac4ab9e3beb67674adbc6a210e2708604 (patch)
tree44400d118d7813a8d7e16a67f074c6696f8868b3 /chrome_frame/bind_context_info.h
parentf1094b0275c82ead4b9aabbda24f5c2b3e8b4a1b (diff)
downloadchromium_src-8ee65baac4ab9e3beb67674adbc6a210e2708604.zip
chromium_src-8ee65baac4ab9e3beb67674adbc6a210e2708604.tar.gz
chromium_src-8ee65baac4ab9e3beb67674adbc6a210e2708604.tar.bz2
Include base/win/scoped_comptr.h instead of base/scoped_comptr_win.h.
Fix up all the callers to use the new location and namespace. Also, delete the stub file since it isn't included by anyone more. (Note: This was a TODO for brettw). BUG=None TEST=None R=brettw@chromium.org Review URL: http://codereview.chromium.org/6825055 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@81303 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome_frame/bind_context_info.h')
-rw-r--r--chrome_frame/bind_context_info.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome_frame/bind_context_info.h b/chrome_frame/bind_context_info.h
index e9add10..7c0e421 100644
--- a/chrome_frame/bind_context_info.h
+++ b/chrome_frame/bind_context_info.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -35,7 +35,7 @@ class __declspec(uuid("00000000-0000-0000-0000-000000000000")) BindContextInfo
// Returns the BindContextInfo instance associated with the bind
// context. Creates it if needed.
// The returned info object will be AddRef-ed on return, so use
// ScopedComPtr<>::Receive() to receive this pointer.
static HRESULT FromBindContext(IBindCtx* bind_context,
BindContextInfo** info);
@@ -106,7 +106,7 @@ class __declspec(uuid("00000000-0000-0000-0000-000000000000")) BindContextInfo
bool is_switching_;
base::win::ScopedComPtr<IUnknown> ftm_;
scoped_refptr<ProtData> prot_data_;
- ScopedComPtr<IInternetProtocol> protocol_;
+ base::win::ScopedComPtr<IInternetProtocol> protocol_;
DISALLOW_COPY_AND_ASSIGN(BindContextInfo);
};
@@ -35,7 +35,7 @@ class __declspec(uuid("00000000-0000-0000-0000-000000000000")) BindContextInfo
// context. Creates it if needed.
// The returned info object will be AddRef-ed on return, so use
- // ScopedComPtr<>::Receive() to receive this pointer.
+ // base::win::ScopedComPtr<>::Receive() to receive this pointer.
static HRESULT FromBindContext(IBindCtx* bind_context,
BindContextInfo** info);